from setuptools import setup, find_packages

setup(
name = 'RistoCalculator',
version = '1.0',
description='Makes Standard Calculations',
author = 'Risto Tammistu',
packages=find_packages(), # Installs all the requirements
)
